# from fastapi import APIRouter

# from src.routes.fornecedor.registre_fornecedor import router

# fornecedores = APIRouter(
#     prefix="/fornecedores", tags=["fornecedores"]
# )

# fornecedores.include_router(router, prefix="")
