# from fastapi import APIRouter


# # Fornecedor
# from src.routes.fornecedor.registre_fornecedor import router

# fornecedores = APIRouter(prefix="/fornecedores", tags=["fornecedores"])
# fornecedores.include_router(router, prefix="")

# # Tickets
# from src.routes.products.ticket import router as ticket

# ticket_prods = APIRouter()

# ticket_prods.include_router(ticket, prefix="/ticket")
