# # # Importar todos os modelos para resolver dependências circulares
# from src.model.user import Usuario, Membro, CNPJCache, Fornecedor
# from src.model.employee import Employees
# from src.model.sale import Sales
# from src.model.carItems import CartItem
# from src.model.caixa import Caixa
# from src.model.customers import Customer

# # Reconstruir todos os modelos
# Usuario.model_rebuild()
# Membro.model_rebuild()
# CNPJCache.model_rebuild()
# Fornecedor.model_rebuild()
# Employees.model_rebuild()
# Sales.model_rebuild()
# CartItem.model_rebuild()
# Caixa.model_rebuild()
# Customer.model_rebuild()
